import java.util.*;
import java.io.*;
import java.awt.*;
import java.awt.event.*;

class Data {
	private static double[][] data;

	public static double data(int sample, int index) {
		return data[sample][index];
	}

	protected Data() {
		data = new double[6][];
		for(int i = 0; i < 6; i++)
			data[i] = new double[10];

		try {
			String str;
			FileReader in = new FileReader("data.txt");
			BufferedReader b = new BufferedReader(in);
			int counter = 0;
			while((str = b.readLine()) != null) {
				String[] temp = str.split("\t");
				for(int i = 0; i < 6; i++)
					data[i][counter] = Double.parseDouble(temp[i]);
				counter++;
			}
			b.close();
			in.close();
		} catch(IOException e) {
			System.err.println("INPUT ERROR.");
		}
	}
}

class Individual {
	private double[] values;

	public double value(int index) {
		return this.values[index];
	}
	public void set_value(int index, double value) {
		this.values[index] = value;
	}

	protected Individual() {
		this.values = new double[26];
	}
}

class DifferentialEvolution {
	private static LinkedList<Individual> population = new LinkedList<Individual>();
	private static Random rnd = new Random();
	private static final int PopulationSize = 100;
	private static final double F = 1.0;
	private static final double CR = 0.50;
	private static final int N = 26;

	private static final double[] STD = {100.0, 100.0, 100.0, 0.050, 0.50, 0.050, 0.50, 0.150,
		0.250, 10.0, 10.0, 0.250, 10.0, 10.0, 0.250, 10.0, 10.0, 0.250, 10.0, 10.0, 0.250, 10.0, 10.0, 0.250, 10.0, 10.0};
	private static Individual bestFitness;

	private static double costFunction(Individual in) {
		double cost = 0.0;
		for(int i = 0; i < N; i++) {
			if(in.value(i) < 0)
				cost += 10000.0*(1.0 - in.value(i));
		}
		if(in.value(7) > in.value(6))
			cost += 10000.0*(1.0 + (in.value(7) - in.value(6)));

		int steps = 5000;
		for(int sample = 0; sample < 6; sample++) {
			double[] rna = new double[steps + 1];
			rna[0] = in.value(9 + 3*sample);
			double[] imgfp = new double[steps + 1];
			imgfp[0] = in.value(10 + 3*sample);
			double[] gfp = new double[steps + 1];
			gfp[0] = Data.data(sample, 0);
			for(int i = 0; i < steps; i++) {
				if(sample <= 2) {
					if((i - (int)(in.value(8 + 3*sample)*steps))%(int)(in.value(6)*steps) <
						(int)(in.value(7)*steps))
						rna[i + 1] = rna[i] + (1.0/steps)*(in.value(0) - (Math.log(2.0)/in.value(3))*rna[i]);
					else
						rna[i + 1] = rna[i] - (1.0/steps)*(Math.log(2.0)/in.value(3))*rna[i];
				} else
					rna[i + 1] = rna[i] + (1.0/steps)*(in.value(1) - (Math.log(2.0)/in.value(3))*rna[i]);
				imgfp[i + 1] = imgfp[i] + (1.0/steps)*(in.value(2) - (Math.log(2.0)/in.value(4))*imgfp[i] -
					(Math.log(2.0)/in.value(5))*imgfp[i]);
				gfp[i + 1] = gfp[i] + (1.0/steps)*((Math.log(2.0)/in.value(5))*imgfp[i] - (Math.log(2.0)/in.value(4))*gfp[i]);
			}
			for(int j = 0; j < 10; j++)
				cost += Math.abs(Data.data(sample, j) - gfp[(int)((5.0/60.0)*j*steps)]);
			if(in.value(8 + 3*sample) > in.value(6))
				cost += 10000.0*(1.0 + (in.value(8 + 3*sample) - in.value(6)));
		}

		return cost;
	}
	public static Individual bestFitness() {
		return bestFitness;
	}

	protected DifferentialEvolution() {
		new Data();
		rnd.setSeed(System.currentTimeMillis());

		for(int i = 0; i < PopulationSize; i++) {
			Individual individual = new Individual();
			for(int j = 0; j < N; j++)
				individual.set_value(j, (1.0 + 0.10*rnd.nextGaussian())*STD[j]);
			population.add(individual);
		}

		for(int i = 0; i < 10000; i++) {
			for(int j = 0; j < PopulationSize; j++) {
				int x = rnd.nextInt(PopulationSize);
				int a, b, c;
				do {
					a = rnd.nextInt(PopulationSize);
				} while(a == x);
				do {
					b = rnd.nextInt(PopulationSize);
				} while(b == a || b == x);
				do {
					c = rnd.nextInt(PopulationSize);
				} while(c == a || c == b || c == x);
				int R = rnd.nextInt(N);

				Individual original = population.get(x);
				Individual candidate = new Individual();
				for(int k = 0; k < N; k++)
					candidate.set_value(k, original.value(k));
				Individual individual1 = population.get(a);
				Individual individual2 = population.get(b);
				Individual individual3 = population.get(c);

				for(int k = 0; k < N; k++) {
					if(rnd.nextInt(N) == R || (rnd.nextGaussian() + 10.0)%1 < CR)
						candidate.set_value(k, individual1.value(k) +
							F*(individual2.value(k) - individual3.value(k)));
				}

				if(costFunction(original) > costFunction(candidate)) {
					population.remove(original);
					population.add(candidate);
				}
			}
		}
		bestFitness = population.get(0);
		for(int i = 1; i < PopulationSize; i++) {
			Individual individual = population.get(i);
			if(costFunction(bestFitness) > costFunction(individual))
				bestFitness = individual;
		}
	}
}

public class Fitting {
	public static void main(String[] args) {
		new DifferentialEvolution();
		for(int i = 0; i < 26; i++)
			System.uot.println(DifferentialEvolution.bestFitness().value(i));
	}
}
